<?php
namespace SupplyTek\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SupplyTek\Utilities\SessionHandler;
// use Zeedhi\Framework\Controller\Metadata;
use Zeedhi\Framework\HTTP\Kernel;

/**
 * Class that handle metadata
 * 
 * @author Danilo D. Vaz
 */
class MetadataSupplyTek /*extends Metadata */
{
    protected $session;

    const ROUTES_WITH_ID = array(
        "categories" => "categories/category",
        "subcategories" => "categories/subcategory",
        "suppliers" => "suppliers/supplier",
        "products" => "products/product"
    );
    const METADATA_DIR = __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'metadata' . DIRECTORY_SEPARATOR . 'views' . DIRECTORY_SEPARATOR;
    
    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * 
     * @param SessionHandler $sessionHandler Object that allows to manipulate session
     * 
     * @return void
     * 
     * @access public
     * @author Danilo D. Vaz
     */
    public function __construct (SessionHandler $sessionHandler)
    {
        $this->session = $sessionHandler;
    }
    
    private function prepareJSON($metadata, $filePath){
        $jsonData = json_decode($metadata, true);
        $path = self::METADATA_DIR.DIRECTORY_SEPARATOR.$filePath;
        if ($jsonData === null) {
            throw JSONFormatException::invalidJSON($path, json_last_error_msg());
        }

        return $jsonData;
    }
    
    private function loadFile($filePath, $type){
        $data = file_get_contents(self::METADATA_DIR.DIRECTORY_SEPARATOR.$filePath.'.'.$type);

        if(strtolower($type) === 'json') {
           // $data = $this->prepareJSON($data, $filePath);
        }

        return $data;
    }
    
    /**
     * Return metadata file
     * 
     * Returns metadata file. Checks if its a commom file, GO file or GU file 
     * according operator access profile.
     * 
     * @param Request $request Object that receives data from the caller
     * @param Response $response Object that sends back data to the caller
     *
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Danilo D. Vaz
     */
    function gravar($texto){
    	//Variável arquivo armazena o nome e extensão do arquivo.
    	$arquivo = "meu_arquivo.txt";
    	
    	//Variável $fp armazena a conexão com o arquivo e o tipo de ação.
    	$fp = fopen($arquivo, "a+");
    
    	//Escreve no arquivo aberto.
    	fwrite($fp, $texto);
    	
    	//Fecha o arquivo.
    	fclose($fp);
    }
     
    public function getMetaDataSupplyTek (Request $request, Response $response)
    {
        try {
            $accessProfile = $this->session->getSessionData('IDPERFILACES');
            $fileName = $request->getParameter('FILE_NAME');
            $parameters = $request->getParameters();
            $type = isset($parameters['type']) ? $request->getParameter('type') : 'json';
            
            //$metadataPath = Kernel::$metadataSource;

            $this->processRouteWithId($fileName);
            
            $commomPath = self::METADATA_DIR . '/commom/' . $fileName . '.' . $type;
            $commomFileExist = file_exists($commomPath);
            
            if ($commomFileExist) {
                $filePath = 'commom/' .  $fileName;
            } else if ($accessProfile == 'GO') {
                $filePath = 'GO/' .  $fileName;
            } else if ($accessProfile == 'GU') {
                $filePath = 'GU/' .  $fileName;
            }
            
            $view = $this->loadFile($filePath, $type);
            
            header('Content-type: application/json');
            header('Accept-Ranges: bytes');
            header('Access-Control-Allow-Credentials: true');
            header("Access-Control-Allow-Origin: {$_SERVER['HTTP_ORIGIN']}");
            
            #$response->setMetadata(array($view));
            
            echo $view;
            die;
        } catch (\Exception $e) {
            //var_dump($e->getMessage());
            throw new \Exception("File '$fileName.$type' not found for $accessProfile access. $e");
        }
    }
    
    /**
     * Process route with id
     * 
     * Checks if route is in routes with id list and process the file name.
     * 
     * @param string $fileName String that receives file name sent from frontend
     *
     * @return void
     * 
     * @access private
     * @author Danilo D. Vaz
     */
    private function processRouteWithId (&$fileName)
    {
        $fileNameArray = explode("/", $fileName);

        if (isset(self::ROUTES_WITH_ID[$fileNameArray[0]]) && isset($fileNameArray[1])) {
            if ($fileNameArray[1] == 'frame') {
                $fileName = str_replace('/frame/', '/', $fileName);
            } else {
                $fileName = self::ROUTES_WITH_ID[$fileNameArray[0]];
            }
        }
    }
    
}